/*
   Copyright(c) 2002-2011 Thetus Corporation. www.thetus.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
package com.thetus.oss.build.core.util;

import java.io.File;

/**
 * This class is something of a hack, but is required in order to keep settings
 * finding and other utility functions consistent without bringing in a
 * maven dependency in the core build utils, which is something we don't want
 * to do.
 * <br />
 * As it stands, the logic is as follows. If the M2_LOCATION environment variable
 * is set, and it points to an extant directory, return the file at that location.
 * If it is not set, return ~/.m2
 *
 */
public class M2LocationUtils {
    public static File getM2Directory() {
        String m2env = System.getenv("M2_LOCATION");
        File m2dir = null;
        if (m2env != null) {
            m2dir = new File(m2env);
            if (!m2dir.exists()) {
                System.err.println("M2_LOCATION set to \"" + m2env + "\" but no such dir exists.");
                System.err.println("Please point M2_LOCATION environment variable to a valid location.");
                m2dir = null;
            }
        }

        if (m2dir == null) {
            m2dir = new File(new File(System.getProperty("user.home")), ".m2");
            if (!m2dir.exists()) {
                m2dir.mkdirs();
            }
        }

        return m2dir;
    }

    public static String getM2Location() {
        return getM2Directory().getAbsolutePath();
    }
}
